@@ -129,6 +129,7 @@ new CloudFrontToApiGateway(this, "test-cloudfront-apigateway", new CloudFrontToA
 |existingApiGatewayObj|[`api.RestApi`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_apigateway.RestApi.html)|The regional API Gateway that will be fronted with the CloudFront|
 |cloudFrontDistributionProps?|[`cloudfront.DistributionProps \| any`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_cloudfront.DistributionProps.html)|Optional user provided props to override the default props for CloudFront Distribution|
 |insertHttpSecurityHeaders?|`boolean`|Optional user provided props to turn on/off the automatic injection of best practice HTTP security headers in all responses from CloudFront|
+| responseHeadersPolicyProps?   | [`cloudfront.ResponseHeadersPolicyProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_cloudfront.ResponseHeadersPolicyProps.html) | Optional user provided configuration that cloudfront applies to all http responses.|
 |cloudFrontLoggingBucketProps?|[`s3.BucketProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_s3.BucketProps.html)|Optional user provided props to override the default props for the CloudFront Logging Bucket.|
 
 ## Pattern Properties
@@ -197,6 +198,7 @@ class CloudFrontToApiGateway(
         cloud_front_distribution_props: typing.Any = None,
         cloud_front_logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
         insert_http_security_headers: typing.Optional[builtins.bool] = None,
+        response_headers_policy_props: typing.Optional[typing.Union[aws_cdk.aws_cloudfront.ResponseHeadersPolicyProps, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''
         :param scope: - represents the scope for all the resources.
@@ -204,7 +206,8 @@ class CloudFrontToApiGateway(
         :param existing_api_gateway_obj: Existing instance of api.RestApi object. Default: - None
         :param cloud_front_distribution_props: Optional user provided props to override the default props. Default: - Default props are used
         :param cloud_front_logging_bucket_props: Optional user provided props to override the default props for the CloudFront Logging Bucket. Default: - Default props are used
-        :param insert_http_security_headers: Optional user provided props to turn on/off the automatic injection of best practice HTTP security headers in all responses from cloudfront. Default: - true
+        :param insert_http_security_headers: Optional user provided props to turn on/off the automatic injection of best practice HTTP security headers in all responses from cloudfront. Turning this on will inject default headers and is mutually exclusive with passing custom security headers via the responseHeadersPolicyProps parameter. Default: - true
+        :param response_headers_policy_props: Optional user provided configuration that cloudfront applies to all http responses. Can be used to pass a custom ResponseSecurityHeadersBehavior, ResponseCustomHeadersBehavior or ResponseHeadersCorsBehavior to the cloudfront distribution. Passing a custom ResponseSecurityHeadersBehavior is mutually exclusive with turning on the default security headers via ``insertHttpSecurityHeaders`` prop. Will throw an error if both ``insertHttpSecurityHeaders`` is set to ``true`` and ResponseSecurityHeadersBehavior is passed. Default: - undefined
 
         :access: public
         :since: 0.8.0
@@ -219,6 +222,7 @@ class CloudFrontToApiGateway(
                 cloud_front_distribution_props: typing.Any = None,
                 cloud_front_logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
                 insert_http_security_headers: typing.Optional[builtins.bool] = None,
+                response_headers_policy_props: typing.Optional[typing.Union[aws_cdk.aws_cloudfront.ResponseHeadersPolicyProps, typing.Dict[str, typing.Any]]] = None,
             ) -> None:
                 ...
             type_hints = typing.get_type_hints(stub)
@@ -229,6 +233,7 @@ class CloudFrontToApiGateway(
             cloud_front_distribution_props=cloud_front_distribution_props,
             cloud_front_logging_bucket_props=cloud_front_logging_bucket_props,
             insert_http_security_headers=insert_http_security_headers,
+            response_headers_policy_props=response_headers_policy_props,
         )
 
         jsii.create(self.__class__, self, [scope, id, props])
@@ -262,6 +267,7 @@ class CloudFrontToApiGateway(
         "cloud_front_distribution_props": "cloudFrontDistributionProps",
         "cloud_front_logging_bucket_props": "cloudFrontLoggingBucketProps",
         "insert_http_security_headers": "insertHttpSecurityHeaders",
+        "response_headers_policy_props": "responseHeadersPolicyProps",
     },
 )
 class CloudFrontToApiGatewayProps:
@@ -272,17 +278,21 @@ class CloudFrontToApiGatewayProps:
         cloud_front_distribution_props: typing.Any = None,
         cloud_front_logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
         insert_http_security_headers: typing.Optional[builtins.bool] = None,
+        response_headers_policy_props: typing.Optional[typing.Union[aws_cdk.aws_cloudfront.ResponseHeadersPolicyProps, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''
         :param existing_api_gateway_obj: Existing instance of api.RestApi object. Default: - None
         :param cloud_front_distribution_props: Optional user provided props to override the default props. Default: - Default props are used
         :param cloud_front_logging_bucket_props: Optional user provided props to override the default props for the CloudFront Logging Bucket. Default: - Default props are used
-        :param insert_http_security_headers: Optional user provided props to turn on/off the automatic injection of best practice HTTP security headers in all responses from cloudfront. Default: - true
+        :param insert_http_security_headers: Optional user provided props to turn on/off the automatic injection of best practice HTTP security headers in all responses from cloudfront. Turning this on will inject default headers and is mutually exclusive with passing custom security headers via the responseHeadersPolicyProps parameter. Default: - true
+        :param response_headers_policy_props: Optional user provided configuration that cloudfront applies to all http responses. Can be used to pass a custom ResponseSecurityHeadersBehavior, ResponseCustomHeadersBehavior or ResponseHeadersCorsBehavior to the cloudfront distribution. Passing a custom ResponseSecurityHeadersBehavior is mutually exclusive with turning on the default security headers via ``insertHttpSecurityHeaders`` prop. Will throw an error if both ``insertHttpSecurityHeaders`` is set to ``true`` and ResponseSecurityHeadersBehavior is passed. Default: - undefined
 
         :summary: The properties for the CloudFrontToApiGateway Construct
         '''
         if isinstance(cloud_front_logging_bucket_props, dict):
             cloud_front_logging_bucket_props = aws_cdk.aws_s3.BucketProps(**cloud_front_logging_bucket_props)
+        if isinstance(response_headers_policy_props, dict):
+            response_headers_policy_props = aws_cdk.aws_cloudfront.ResponseHeadersPolicyProps(**response_headers_policy_props)
         if __debug__:
             def stub(
                 *,
@@ -290,6 +300,7 @@ class CloudFrontToApiGatewayProps:
                 cloud_front_distribution_props: typing.Any = None,
                 cloud_front_logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
                 insert_http_security_headers: typing.Optional[builtins.bool] = None,
+                response_headers_policy_props: typing.Optional[typing.Union[aws_cdk.aws_cloudfront.ResponseHeadersPolicyProps, typing.Dict[str, typing.Any]]] = None,
             ) -> None:
                 ...
             type_hints = typing.get_type_hints(stub)
@@ -297,6 +308,7 @@ class CloudFrontToApiGatewayProps:
             check_type(argname="argument cloud_front_distribution_props", value=cloud_front_distribution_props, expected_type=type_hints["cloud_front_distribution_props"])
             check_type(argname="argument cloud_front_logging_bucket_props", value=cloud_front_logging_bucket_props, expected_type=type_hints["cloud_front_logging_bucket_props"])
             check_type(argname="argument insert_http_security_headers", value=insert_http_security_headers, expected_type=type_hints["insert_http_security_headers"])
+            check_type(argname="argument response_headers_policy_props", value=response_headers_policy_props, expected_type=type_hints["response_headers_policy_props"])
         self._values: typing.Dict[str, typing.Any] = {
             "existing_api_gateway_obj": existing_api_gateway_obj,
         }
@@ -306,6 +318,8 @@ class CloudFrontToApiGatewayProps:
             self._values["cloud_front_logging_bucket_props"] = cloud_front_logging_bucket_props
         if insert_http_security_headers is not None:
             self._values["insert_http_security_headers"] = insert_http_security_headers
+        if response_headers_policy_props is not None:
+            self._values["response_headers_policy_props"] = response_headers_policy_props
 
     @builtins.property
     def existing_api_gateway_obj(self) -> aws_cdk.aws_apigateway.RestApi:
@@ -341,11 +355,32 @@ class CloudFrontToApiGatewayProps:
     def insert_http_security_headers(self) -> typing.Optional[builtins.bool]:
         '''Optional user provided props to turn on/off the automatic injection of best practice HTTP security headers in all responses from cloudfront.
 
+        Turning this on will inject default headers and is mutually exclusive with passing custom security headers
+        via the responseHeadersPolicyProps parameter.
+
         :default: - true
         '''
         result = self._values.get("insert_http_security_headers")
         return typing.cast(typing.Optional[builtins.bool], result)
 
+    @builtins.property
+    def response_headers_policy_props(
+        self,
+    ) -> typing.Optional[aws_cdk.aws_cloudfront.ResponseHeadersPolicyProps]:
+        '''Optional user provided configuration that cloudfront applies to all http responses.
+
+        Can be used to pass a custom ResponseSecurityHeadersBehavior, ResponseCustomHeadersBehavior or
+        ResponseHeadersCorsBehavior to the cloudfront distribution.
+
+        Passing a custom ResponseSecurityHeadersBehavior is mutually exclusive with turning on the default security headers
+        via ``insertHttpSecurityHeaders`` prop. Will throw an error if both ``insertHttpSecurityHeaders`` is set to ``true``
+        and ResponseSecurityHeadersBehavior is passed.
+
+        :default: - undefined
+        '''
+        result = self._values.get("response_headers_policy_props")
+        return typing.cast(typing.Optional[aws_cdk.aws_cloudfront.ResponseHeadersPolicyProps], result)
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
